@@ -11,7 +11,7 @@ mydir = os.path.dirname(os.path.realpath(__file__))
 
 class TestSweeper(unittest.TestCase):
     def test_file_dups_dups(self):
-        dups = file_dups([os.path.join(mydir, 'testfiles_dups')], 'md5')
+        dups = file_dups([os.path.join(mydir, 'testfiles_dups')])
         dups_exist = False
         for h, flist in dups.items():
             if len(flist) > 1:
@@ -19,7 +19,7 @@ class TestSweeper(unittest.TestCase):
         self.assertTrue(dups_exist)
 
     def test_file_dups_nodups(self):
-        dups = file_dups([os.path.join(mydir, 'testfiles_nodups')], 'md5')
+        dups = file_dups([os.path.join(mydir, 'testfiles_nodups')])
         for h, flist in dups.items():
             self.assertTrue(len(flist) == 1)
 
